# -*- encoding: utf-8 -*-
##############################################################################
#
#    OpenERP, Open Source Management Solution
#    Copyright (c) 2017 Eynes (http://www.eynes.com.ar)
#    All Rights Reserved. See AUTHORS for details.
#
#    This program is free software: you can redistribute it and/or modify
#    it under the terms of the GNU Affero General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU Affero General Public License for more details.
#
#    You should have received a copy of the GNU Affero General Public License
#    along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
##############################################################################

from odoo import api, fields, models, _

class ProductTemplate(models.Model):
    _inherit = 'product.template'

    picking_type_id = fields.Many2one('stock.picking.type', string='Operation Type')
    subcontracting_service_proc_rule_id = fields.Many2one(
        comodel_name='procurement.rule',
        string="Subcontracting Service Procurement Rule"
    )
    no_chain_move = fields.Boolean('Do not chain moves', default=False,
        help="If enabled no chain of moves would happen")


class MrpProduction(models.Model):
    _inherit = 'mrp.production'

    @api.model
    def create(self, values):
        if values.get('product_id'):
            pti = self.env['product.product'].browse(values['product_id'])
            if pti and pti.product_tmpl_id.picking_type_id:
                values['picking_type_id'] = pti.product_tmpl_id.picking_type_id.id
                values['location_src_id'] = pti.product_tmpl_id.picking_type_id.default_location_src_id.id
                values['location_dest_id'] = pti.product_tmpl_id.picking_type_id.default_location_dest_id.id

        production = super(MrpProduction, self).create(values)
        return production

    def _generate_finished_moves(self):
        picking_type_id = False
        ##
        if self.picking_type_id.code != 'mrp_operation':
            picking_type_id = self.picking_type_id.id
        ##
        move = self.env['stock.move'].create({
            'name': self.name,
            'date': self.date_planned_start,
            'date_expected': self.date_planned_start,
            'product_id': self.product_id.id,
            'product_uom': self.product_uom_id.id,
            'product_uom_qty': self.product_qty,
            'location_id': self.product_id.property_stock_production.id,
            'location_dest_id': self.location_dest_id.id,
            'company_id': self.company_id.id,
            'production_id': self.id,
            'origin': self.name,
            'group_id': self.procurement_group_id.id,
            'picking_type_id': picking_type_id,
            'propagate': self.propagate,
            'move_dest_ids': [(4, x.id) for x in self.move_dest_ids],
        })
        move._action_confirm()
        return move
